#[non_exhaustive]pub enum OperationalError {
InvalidCatalog {
reason: &'static str,
},
InvalidProviderPack {
reason: &'static str,
},
InvalidLanguageIntelligenceInput {
reason: &'static str,
},
InvalidIntermediateRepresentation {
reason: &'static str,
},
}Expand description
Failure in execution inputs or internal pipeline invariants, not in Stack source.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidCatalog
A provided catalog violates an invariant required by pure execution.
InvalidProviderPack
A provider pack violates safe deterministic rendering invariants.
InvalidLanguageIntelligenceInput
A language-intelligence request violates its stateless input contract.
InvalidIntermediateRepresentation
Compiler or layout data violates an invariant required by pure execution.