pub struct Diagnostic {
pub code: String,
pub severity: Severity,
pub message: String,
pub range: SourceRange,
pub expected: Vec<String>,
pub help: Option<String>,
pub related: Vec<RelatedInformation>,
}Expand description
Engine-owned portable diagnostic shared by native and future WASM outputs.
Fields
code: StringStable Stack diagnostic identifier.
severity: SeverityWhether the diagnostic prevents an artifact from being produced.
message: StringConcise human-readable diagnostic description.
range: SourceRangePrimary end-exclusive source range.
expected: Vec<String>Ordered source values or constructs valid at the primary range.
help: Option<String>Optional corrective guidance.
Other source locations involved in the diagnostic.