pub struct EngineMetadata {
pub engine_version: String,
pub language_version: Option<LanguageVersion>,
pub theme_catalog_version: String,
pub theme_catalog_revision: String,
}Expand description
Version metadata attached to every operation output.
Fields
engine_version: StringSemantic version of stack-engine.
language_version: Option<LanguageVersion>Authored language version, absent when decoding or syntax parsing fails.
theme_catalog_version: StringSemantic version of the selected theme catalog.
theme_catalog_revision: StringContent revision of the selected theme catalog and icon bytes.