pub struct ProviderNoticeIcon {
pub id: String,
pub product_name: String,
pub brand_source_url: Option<String>,
pub brand_guidelines_url: Option<String>,
pub source_id: String,
}Expand description
One provider icon listed in a rendered-artifact notice.
Fields
id: StringNamespaced provider icon identifier.
product_name: StringOfficial provider product name.
brand_source_url: Option<String>Rights-owner source for this brand icon, when the archive is multi-brand.
brand_guidelines_url: Option<String>Rights-owner usage guidelines for this brand icon, when available.
source_id: StringPack-local source ID, or primary for the primary source.